@@ -139,9 +139,9 @@ class SAML2Tests(TestCase):
             came_from,
         )
         self.saml_session.save()
-        self.client.cookies[
-            settings.SESSION_COOKIE_NAME
-        ] = self.saml_session.session_key
+        self.client.cookies[settings.SESSION_COOKIE_NAME] = (
+            self.saml_session.session_key
+        )
 
     def b64_for_post(self, xml_text, encoding="utf-8"):
         return base64.b64encode(xml_text.encode(encoding)).decode("ascii")
@@ -308,8 +308,12 @@ class SAML2Tests(TestCase):
             metadata_file="remote_metadata_three_idps.xml",
         )
 
-        response = self.client.get(reverse("saml2_login") + "?idp=<b>https://unknown.org</b>")
-        self.assertContains(response, "&lt;b&gt;https://unknown.org&lt;/b&gt;", status_code=403)
+        response = self.client.get(
+            reverse("saml2_login") + "?idp=<b>https://unknown.org</b>"
+        )
+        self.assertContains(
+            response, "&lt;b&gt;https://unknown.org&lt;/b&gt;", status_code=403
+        )
 
     def test_login_authn_context(self):
         sp_kwargs = {
