@@ -26,4 +26,4 @@ sys.path.append(PROJECT_DIR)
 # Load models
 application = get_wsgi_application()
 
-management.call_command("test", "djangosaml2.tests", "testprofiles")
+management.call_command("test", "djangosaml2.tests", "testprofiles", "-v", "2")
